@@ -8,8 +8,7 @@ use Scalar::Util qw/ reftype /;
 use Data::Dumper;
 use XML::XPathScript::Template::Tag;
 
-
-{
+our $VERSION = '1.46_01';
 
 sub new {
    my( $class ) = @_;
@@ -21,10 +20,10 @@ sub new {
 }
 
 
-sub set {
+sub set {       ##no critic
     croak "method set called with more than two arguments" if @_ > 3;
 
-	my( $self, $tag, $attribute_ref ) = @_;
+    my( $self, $tag, $attribute_ref ) = @_;
 
     my $type = reftype $tag;
     my @templates =         # templates to change
@@ -38,7 +37,7 @@ sub set {
 
     $_->set( $attribute_ref ) for @templates;
 
-	return;
+    return;
 }
 
 sub copy { 
@@ -65,7 +64,7 @@ sub alias {
 }
 
 
-sub dump {
+sub dump {                      ##no critic
     my( $self, @tags ) = @_;
     
     my %template = %{$self};
@@ -80,7 +79,10 @@ sub dump {
 sub clear {
     my( $self, $tags ) = @_;
 
-    delete $self->{ $_ } for $tags ? @$tags : grep { !/^:/ } keys %$self;
+    delete $self->{ $_ } for $tags 
+                                ? @$tags 
+                                : grep { !/^:/ } keys %$self; ##no critic
+    return;
 }
 
 
@@ -119,16 +121,15 @@ sub resolve {
     no warnings qw/ uninitialized /;
     $namespace = ':'.$namespace;
 
-    return ( ( $template->{$namespace} && 			# selection order
-                (  $template->{$namespace}{$tag} 	# foo:bar
+    return ( ( $template->{$namespace} &&           # selection order
+                (  $template->{$namespace}{$tag}    # foo:bar
                 || $template->{$namespace}{'*'} ) ) # foo:*
                 || $template->{$tag}                # bar
                 || $template->{'*'} );              # *  
                                                     # (and undef if nothing)
 }
 
-'end of XML::XPathScript::Template';
-}
+1;
 
 __END__
 
@@ -166,20 +167,18 @@ A stylesheet's template defines the transformations and actions that
 are performed on the tags of a document as they are processed.
 
 The template of a stylesheet can be accessed via variables 
-I<$t> and I<$template>.
+I<$t>, I<$template> and I<$XML::XPathScript::trans>.
 
 
 =head1 METHODS
 
-=over
+=head2 new
 
-=item new
-
-    $template = new XML::XPathScript::Template;
+    $template = XML::XPathScript::Template->new
 
 Creates and returns a new, empty template.
 
-=item  set
+=head2  set
 
     $template->( $tag, \%attributes )
     $template->set_template( \@tags , \%attributes )
@@ -191,7 +190,7 @@ Example:
 
     $template->set( 'foo' => { pre => '<a>', post => '</a>' } );
 
-=item copy
+=head2 copy
 
     $template->copy( $original_tag, $copy_tag );
     $template->copy( $original_tag, $copy_tag, \@attributes );
@@ -212,10 +211,10 @@ Example:
     $template->copy( 'important' => [ qw/ urgent redHot / ], 
                         [ qw/ pre post / ] );
 
-=item alias
+=head2 alias
 
-    $template->alias( $original_tag => $alias_tag );
-    $template->alias( $original_tag => \@alias_tags );
+    $template->alias( $original_tag => $alias_tag )
+    $template->alias( $original_tag => \@alias_tags )
 
 Makes the target tags aliases to the original tag. Further
 modifications that will be done on any of these tags will 
@@ -224,16 +223,18 @@ be reflected on all others.
 Example:
 
     $template->alias( 'foo' => 'bar' );
-    $template->set( 'bar' => { pre => '<u>' } );  # also modify 'foo'
+                            
+    # also modifies 'foo'
+    $template->set( 'bar' => { pre => '<u>' } );  
 
 
-=item is_alias
+=head2 is_alias
 
     @aliases = $template->is_alias( $tag )
 
 Returns all tags that are aliases to $tag. 
 
-=item unalias
+=head2 unalias
 
     $template->unalias( $tag )
 
@@ -248,7 +249,7 @@ Example:
     $template->set( 'bar' => { pre => '<c>' } );    # affects only bar
     $template->set( 'baz' => { pre => '<b>' } );    # affects foo and baz
 
-=item clear
+=head2 clear
 
     $template->clear()
     $template->clear( \@tags )
@@ -259,7 +260,7 @@ Example:
 
     $template->clear([ 'foo', 'bar' ]);
 
-=item dump
+=head2 dump
 
     $template->dump()
     $template->dump( @tags )
@@ -272,16 +273,16 @@ Example:
     <%= $template->dump( 'foo' ) %>
     
     # will yield something like
-
+    #
     # $template = {
-    #                'foo' => {
-    #                            'post' => '</bar>',
-    #                            'pre' => '<bar>'
-    #                        }
-    #             };
+    #    foo => {
+    #        post => '</bar>',
+    #        pre  => '<bar>',
+    #    }
+    # };
 
 
-=item namespace
+=head2 namespace
 
     my $subtemplate = $template->namespace( $uri );
 
@@ -293,7 +294,7 @@ Example:
     my $subtemplate = $template->namespace( 'http://www.www3c.org/blah/' );
     $subtemplate->set( 'foo' => { 'pre' => "within 'blah' namespace" } );
 
-=item resolve
+=head2 resolve
 
     $tag = $template->resolve( $namespace, $tagname );
     $tag = $template->resolve( $tagname );
@@ -339,8 +340,6 @@ Example:
     $template->resolve( 'http://blah', 'foo' )->get( 'pre' );  # returns 'c'
     $template->resolve( 'http://blah', 'baz' )->get( 'pre' );  # returns 'd'
 
-=back
-
 =head1 BACKWARD COMPATIBILITY
 
 Prior to version 1.0 of XML::XPathScript, the template of a
@@ -379,17 +378,15 @@ access methods.
         $t->alias( important => alert );
     %>
 
-=head1 BUGS AND LIMITATIONS
+=head1 BUGS 
 
-There are no known bugs in this module.
-
-Please report problems to Yanick Champoux <yanick@cpan.org>
-
-Patches are welcome.
+Please send bug reports to <bug-xml-xpathscript@rt.cpan.org>,
+or via the web interface at 
+http://rt.cpan.org/Public/Dist/Display.html?Name=XML-XPathScript .
 
 =head1 AUTHOR
 
-Yanick Champoux (yanick@cpan.org)
+Yanick Champoux <yanick@cpan.org>
 
 =cut
 
