@@ -1,9 +1,7 @@
 package Apache::AxKit::Language::YPathScript;
 
 use strict;
-use vars qw( @ISA $VERSION $stash );
 
-@ISA = qw/ Apache::AxKit::Language XML::XPathScript /;
 
 =head1 NAME
 
@@ -63,7 +61,10 @@ use Apache::AxKit::Exception;
 use Apache::AxKit::CharsetConv;
 use XML::XPathScript; 
 
-$VERSION = 1.4;
+use vars qw( @ISA $VERSION $stash );
+@ISA = qw/ Apache::AxKit::Language XML::XPathScript /;
+
+$VERSION = '1.46_01';
 
 =head2 Functions
 
@@ -106,16 +107,18 @@ sub handler
     AxKit::Debug(6, "YPathScript: Getting XML Source");
   
 	# try to find the XML document
-	$xps->{xml} = $r->pnotes('dom_tree')                       # dom_tree is an XML::LibXML DOM
+    my $xml = $r->pnotes('dom_tree')                       # dom_tree is an XML::LibXML DOM
 	   	     	|| $r->pnotes('xml_string')
 		     	|| get_source_tree($xml_provider);
    
-    AxKit::Debug(7, "XML retrieved: $xps->{xml}\n");
+    AxKit::Debug(7, "XML retrieved: $xml\n");
+
+    $xps->set_xml( $xml );
 
 	# $xpath->set_context($source_tree);   what does this do?
 
 	AxKit::Debug( 6, "Recompiling stylesheet\n" );
-	$xps->{stylesheet} = get_source_tree($style_provider);
+	$xps->set_stylesheet( get_source_tree($style_provider) );
 	
 	#$xps->get_stylesheet( $style_provider );
 
@@ -294,7 +297,7 @@ sub document {
     my( $self, $uri ) = @_;
 
 	my( $results, $parser );	
-	if( $XML_parser eq 'XML::XPath' ) {
+	if( $XML::XPathScript::XML_parser eq 'XML::XPath' ) {
 		my $xml_parser = XML::Parser->new(
 				ErrorContext => 2,
 				Namespaces => $XML::XPath::VERSION < 1.07 ? 1 : 0,
@@ -303,11 +306,11 @@ sub document {
 	
 		$parser = XML::XPath::XMLParser->new(parser => $xml_parser);
 		$results = XML::XPath::NodeSet->new();
-	} elsif {
-		$parser = new XML::LibXML;
-		$result = new XML::LibXML::Node;
+	} else {
+		$parser = XML::LibXML->new();
+		$results = XML::LibXML::Node->new();
 	}
-	
+
     my $newdoc;
     if ($uri =~ /^axkit:/) {
         $newdoc = $parser->parse( AxKit::get_axkit_uri($uri) );
@@ -349,3 +352,21 @@ sub document {
 }
 
 'Apache::AxKit::Language::YPathScript';
+
+__END__
+
+=back
+
+=head1 BUGS
+
+Please send bug reports to <bug-xml-xpathscript@rt.cpan.org>,
+or via the web interface at 
+http://rt.cpan.org/Public/Dist/Display.html?Name=XML-XPathScript .
+
+=head1 AUTHOR 
+
+Yanick Champoux <yanick@cpan.org>
+
+Original Axkit::Apache::AxKit::Language module 
+by Matt Sergeant <matt@sergeant.org>
+
