@@ -9,7 +9,7 @@ use base qw( Apache2::TomKit::Processor::AbstractProcessor XML::XPathScript );
 use Apache2::TomKit::Processor::DefinitionProvider::FileSystemProvider;
 use XML::LibXML;
 
-# $Id$
+our $VERSION = '1.46_01';
 
 sub new {
     my $class  = shift;
@@ -38,9 +38,9 @@ sub setUp {
     if( $this->{processordef}->isFile() ) {
         open my $STYLESHEET, $this->{processordef}->getInstructions();
         local $/ = undef;
-        $this->{stylesheet} = <$STYLESHEET>;
+        $this->set_stylesheet( <$STYLESHEET> );
     } else {
-    	$this->{stylesheet} = $this->{processordef}->getInstructions();
+        $this->set_stylesheet( $this->{processordef}->getInstructions() );
     }
     
     $this->{logger}->debug( 9, "XPathScript: stylesheet is $this->{stylesheet}" );
@@ -54,12 +54,11 @@ sub process {
     $this->{logger}->debug( 9,
         "XPathScript: Is processing the source with stylesheet: " . $this->{processordef} );
 
-	$this->{xml} = $input;
+    $this->set_xml( $input );
 	$this->{logger}->debug( 9, "XPathScript: source is $input" );
 	
 	my $output;
 	$this->{printer} = \$output;
-	$this->{dom} = $this->{xml};
 
 	{
 		local *ORIGINAL_STDOUT;
@@ -111,4 +110,35 @@ sub getProcessorDefinition {
 }
 
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 NAME
+
+Apache2::TomKit::Processor::XPathScript - XPathScript Processor for TomKit
+
+=head1 SYNOPSIS
+
+ # in the relevant .htaccess
+ PerlSetVar AxAddProcessorMap "text/xps=>Apache2::TomKit::Processor::XPathScript"
+
+ <Files *\.xml>
+     PerlFixupHandler Apache2::TomKit
+     PerlSetVar AxAddProcessorDef "text/xps=>stylesheet.xps"
+ </Files>
+
+=head1 BUGS
+
+Please send bug reports to <bug-xml-xpathscript@rt.cpan.org>,
+or via the web interface at 
+http://rt.cpan.org/Public/Dist/Display.html?Name=XML-XPathScript .
+
+=head1 AUTHOR 
+
+Yanick Champoux <yanick@cpan.org>
+
+Original Axkit::Apache::AxKit::Language module 
+by Matt Sergeant <matt@sergeant.org>
+
+
